@@ -7,7 +7,7 @@ use bytes::{Buf, Bytes};
 #[derive(Debug, Clone, PartialEq)]
 pub struct Connect {
     /// Mqtt protocol version
-    protocol: Protocol,
+    pub protocol: Protocol,
     /// Mqtt keep alive time
     pub keep_alive: u16,
     /// Client Id
@@ -420,8 +420,8 @@ impl WillProperties {
 
 #[derive(Debug, Clone, PartialEq)]
 pub struct Login {
-    username: String,
-    password: String,
+    pub username: String,
+    pub password: String,
 }
 
 impl Login {
